/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import java.io.Serializable;
import java.util.List;
import org.locationtech.jts.geom.Geometry;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

/**
 * 定位标签JPA
 * @author LJ-2204
 * 2022/4/14
 */

@Repository
public interface LocationTagRepository
    extends JpaRepository<LocationTag, Serializable>, JpaSpecificationExecutor<LocationTag> {
    /**
     * 查询在指定区域内的所有标签
     * @param geometry 指定区域
     * @return 标签
     */
    @Query(value = "SELECT * FROM BS_LOCATION_TAG bl WHERE ST_Contains(?1, bl.point)", nativeQuery = true)
    List<LocationTag> findInArea(Geometry geometry);

    /**
     * 查询在指定区域内的所有标签数量
     * @param geometry 指定区域
     * @return 标签数量
     */
    @Query(value = "SELECT count(*) FROM BS_LOCATION_TAG bl WHERE ST_Contains(?1, bl.point)", nativeQuery = true)
    int findInAreaNum(Geometry geometry);

    /**
     * 根据多个员工id查询定位标签
     * @param userIds 员工id集
     * @return 定位标签
     */
    @Query(value = "SELECT * FROM BS_LOCATION_TAG  WHERE user_id IN (?1)", nativeQuery = true)
    List<LocationTag> findByUserIds(List<Long> userIds);

    /**
     * 查询距离指定区域多少米的标签
     * @param geometry 指定区域
     * @param distance 距离(米)
     * @return 定位标签
     */
    @Query(value = "SELECT * FROM BS_LOCATION_TAG WHERE st_distance(point, :geometry) < :distance", nativeQuery = true)
    List<LocationTag> findByDistance(@Param("geometry") Geometry geometry, @Param("distance") Integer distance);
}
