/* (C) 2022 YiRing, Inc. */
package com.yiring.app.util;

import com.yiring.common.constant.RegEx;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/14 14:06
 */
public class TimeUtil {

    /**
     * 判断一个时间是否在配置的时间内
     * @param time 判断的时间
     * @param beginTime 配置的开始时间
     * @param endTime 配置的结束时间
     * @return true:在 false:不在
     */
    public static boolean judgeTime(LocalDateTime time, String beginTime, String endTime) {
        if (!beginTime.matches(RegEx.TIME_RULE) || !endTime.matches(RegEx.TIME_RULE)) {
            throw new IllegalArgumentException("时间格式不正确");
        }
        DateTimeFormatter pattern = DateTimeFormatter.ofPattern("E HH:mm:ss");
        String source = time.format(pattern);
        int beginWeek = transform(beginTime.charAt(2));
        int endWeek = transform(endTime.charAt(2));
        int nowWeek = transform(source.charAt(1));
        if (nowWeek < beginWeek || nowWeek > endWeek) {
            return false;
        }
        int beginHour = Integer.parseInt(beginTime.substring(4, 6));
        int endHour = Integer.parseInt(endTime.substring(4, 6));
        int nowHour = Integer.parseInt(beginTime.substring(3, 5));
        if (nowHour < beginHour || nowHour > endHour) {
            return false;
        }
        int beginMinute = Integer.parseInt(beginTime.substring(7, 9));
        int endMinute = Integer.parseInt(endTime.substring(7, 9));
        int nowMinute = Integer.parseInt(beginTime.substring(6, 8));
        if (nowMinute < beginMinute || nowHour > endMinute) {
            return false;
        }
        int beginSecond = Integer.parseInt(beginTime.substring(10));
        int endSecond = Integer.parseInt(endTime.substring(10));
        int nowSecond = Integer.parseInt(beginTime.substring(9));
        if (nowSecond < beginSecond || nowSecond > endSecond) {
            return false;
        }
        return true;
    }

    private static int transform(char source) {
        return switch (source) {
            case '一' -> 1;
            case '二' -> 2;
            case '三' -> 3;
            case '四' -> 4;
            case '五' -> 5;
            case '六' -> 6;
            case '日' -> 7;
            default -> 1;
        };
    }
}
