/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.key;

import cn.hutool.core.util.ObjectUtil;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.key.KeyAlarmLog;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 按键报警推送
 *
 * @author LJ-2204
 * @date 2022/5/13
 */

@ApiModel("KeyAlarmLogVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class KeyAlarmLogVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 9135155632502530938L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "111")
    Long id;

    @ApiModelProperty(value = "用户", example = "111")
    UserVo userVo;

    @ApiModelProperty(value = "通知方式", example = "SMS/APP")
    String type;

    @ApiModelProperty(value = "接收状态", example = "T/F")
    Boolean status;

    @ApiModelProperty(value = "接收时间", example = "2011-11-11 22:22:22")
    LocalDateTime updateTime;

    public static KeyAlarmLogVo transform(KeyAlarmLog keyAlarmLog) {
        KeyAlarmLogVo keyAlarmLogVo = KeyAlarmLogVo
            .builder()
            .id(keyAlarmLog.getId())
            .type(keyAlarmLog.getTypes())
            .status(keyAlarmLog.getStatus())
            .updateTime(keyAlarmLog.getUpdateTime())
            .build();
        if (ObjectUtil.isNotEmpty(keyAlarmLog.getUser())) {
            User user = keyAlarmLog.getUser();
            keyAlarmLogVo.setUserVo(
                UserVo.builder().id(user.getId()).realName(user.getRealName()).mobile(user.getMobile()).build()
            );
        }
        return keyAlarmLogVo;
    }
}
