/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.rehearsal;

import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.app.param.rehearsal.RehearsalPlanAddParam;
import com.yiring.app.param.rehearsal.RehearsalPlanConditionParam;
import com.yiring.app.param.rehearsal.RehearsalPlanModifyParam;
import com.yiring.app.param.rehearsal.RehearsalPlanPlaybackParam;
import com.yiring.app.service.rehearsal.RehearsalPlanService;
import com.yiring.app.vo.rehearsal.RehearsalPlanRealTimeVo;
import com.yiring.app.vo.rehearsal.RehearsalPlanVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.Objects;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import org.springframework.data.domain.Sort;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/10 14:08
 */
@Validated
@SuppressWarnings({ "deprecation" })
@Api(tags = "演练计划", description = "RehearsalPlan")
@RestController
@RequestMapping("/rehearsal/plan")
public class RehearsalPlanController {

    @Resource
    private RehearsalPlanService rehearsalPlanService;

    @ApiOperation("添加一条演练计划")
    @PostMapping("/addOne")
    public Result<String> addOne(@Valid RehearsalPlanAddParam param) {
        return rehearsalPlanService.addOne(param);
    }

    @ApiOperation("修改一条演练计划")
    @PostMapping("/modifyOne")
    public Result<String> modifyOne(@Valid RehearsalPlanModifyParam param) {
        return rehearsalPlanService.modifyOne(param);
    }

    @ApiOperation("删除一条演练计划")
    @PostMapping("/removeOne")
    public Result<String> removeOne(@Valid IdParam idParam) {
        return rehearsalPlanService.removeOne(idParam);
    }

    @ApiOperation("查询一条演练计划")
    @GetMapping("/findOne")
    public Result<RehearsalPlanVo> findOne(@Valid IdParam idParam) {
        return rehearsalPlanService.findOne(idParam);
    }

    @ApiOperation("查询演练计划列表")
    @GetMapping("/findList")
    public Result<PageVo<RehearsalPlanVo>> findList(
        @Valid RehearsalPlanConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        if (Objects.isNull(pageParam.getSortField())) {
            pageParam.setSortField(AlarmType.Fields.createTime);
            pageParam.setSortOrder(Sort.Direction.DESC);
        }
        return rehearsalPlanService.findList(conditionParam, pageParam);
    }

    @ApiOperation(value = "导出演练计划", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @GetMapping("/export")
    public void export(@Valid RehearsalPlanConditionParam conditionParam, HttpServletResponse response) {
        rehearsalPlanService.export(conditionParam, response);
    }

    @ApiOperation("启动一个演练计划")
    @PostMapping("/start")
    public Result<String> start(@Valid IdParam idParam) {
        return rehearsalPlanService.start(idParam);
    }

    @ApiOperation("停止一个演练计划")
    @PostMapping("/stop")
    public Result<String> stop(@Valid IdParam idParam) {
        return rehearsalPlanService.stop(idParam);
    }

    @ApiOperation("实时查看演练")
    @GetMapping("/findRealTime")
    public Result<RehearsalPlanRealTimeVo> findRealTime(@Valid IdParam idParam) {
        return rehearsalPlanService.findRealTime(idParam);
    }

    @ApiOperation("查看回放")
    @GetMapping("/findPlayback")
    public Result<PageVo<RehearsalPlanRealTimeVo>> findPlayback(@Valid RehearsalPlanPlaybackParam param) {
        return rehearsalPlanService.findPlayback(param);
    }
}
